@@ -19,6 +19,7 @@ from devpi import __version__ as client_version
 from pluggy import HookimplMarker
 from pluggy import PluginManager
 from shutil import rmtree
+import stat
 from tempfile import mkdtemp
 import json
 subcommand = lazydecorator()
@@ -229,6 +230,10 @@ class Hub:
 
     @contextmanager
     def workdir(self, prefix='devpi-'):
+        def remove_readonly(func, path, excinfo):
+            os.chmod(path, stat.S_IWRITE)
+            func(path)
+
         workdir = py.path.local(
             mkdtemp(prefix=prefix))
 
@@ -236,16 +241,30 @@ class Hub:
         try:
             yield workdir
         finally:
-            rmtree(workdir.strpath)
+            rmtree(workdir.strpath, onerror=remove_readonly)
 
     @cached_property
     def current(self):
         self.clientdir.ensure(dir=1)
-        index_arg = getattr(self.args, "index", None)
-        url = os.environ.get("DEVPI_INDEX", index_arg)
         current = PersistentCurrent(self.auth_path, self.current_path)
+        url = getattr(self.args, "index", None)
+        if "DEVPI_INDEX" in os.environ:
+            if url is None:
+                if current.index is None:
+                    url = current.root_url
+                else:
+                    url = current.index_url
+            else:
+                url = URL(url)
+            devpi_index = os.environ["DEVPI_INDEX"]
+            url = url.joinpath(devpi_index)
+            if not current.root_url.is_valid_http_url() and not url.is_valid_http_url():
+                self.fatal(
+                    "No server set and DEVPI_INDEX from environment is not a "
+                    "full valid URL: %s" % devpi_index)
+            self.info("Using DEVPI_INDEX from environment: %s" % devpi_index)
         if url is not None:
-            current = current.switch_to_local(self, url, None)
+            current = current.switch_to_local(self, URL(url).url, None)
         return current
 
     def get_existing_file(self, arg):
@@ -557,8 +576,22 @@ def try_argcomplete(parser):
 
 
 def print_version(hub):
-    hub.line("devpi-client %s\n" % client_version)
+    hub.line("devpi-client %s" % client_version)
+    version_info = set()
+    for plug, distinfo in hub.pm.list_plugin_distinfo():
+        if distinfo.project_name == "devpi-client":
+            continue
+        key = (distinfo.project_name, distinfo.version)
+        if key in version_info:
+            continue
+        version_info.add(key)
+    if version_info:
+        hub.line()
+        hub.info("plugins:")
+        for item in sorted(version_info):
+            hub.line("    %s %s" % item)
     if hub.current.root_url is not None:
+        hub.line()
         url = hub.current.root_url.addpath('+status').url
         try:
             r = HTTPReply(hub.http.get(
