@@ -213,6 +213,85 @@ def test_fail_push(monkeypatch, tmpdir):
         assert e.code==1
 
 
+def test_derive_token_non_token():
+    class MockHub:
+        pass
+    hub = MockHub()
+    hub.derive_token = Hub.derive_token.__get__(hub)
+    assert hub.derive_token("foo", None) == "foo"
+
+
+@pytest.mark.skipif("sys.version_info >= (3, 6)")
+@pytest.mark.parametrize("prefix", ["devpi", "pypi"])
+def test_derive_token_old_python(prefix):
+    class MockHub:
+        pass
+    hub = MockHub()
+    hub.derive_token = Hub.derive_token.__get__(hub)
+    assert hub.derive_token("%s-foo" % prefix, None) == "%s-foo" % prefix
+
+
+@pytest.mark.skipif("sys.version_info < (3, 6)")
+@pytest.mark.parametrize("prefix", ["devpi", "pypi"])
+def test_derive_token_invalid_token(prefix):
+    msgs = []
+
+    class MockHub:
+        def warn(self, msg):
+            msgs.append(msg)
+    hub = MockHub()
+    hub.derive_token = Hub.derive_token.__get__(hub)
+    hub.derive_token("%s-foo" % prefix, None) == "%s-foo" % prefix
+    (msg,) = msgs
+    assert "can not parse it" in msg
+
+
+@pytest.mark.skipif("sys.version_info < (3, 6)")
+def test_derive_token():
+    import pypitoken.token
+    token = pypitoken.token.Token.create(
+        domain="example.com",
+        identifier="devpi",
+        key="secret")
+    passwd = token.dump()
+    msgs = []
+
+    class MockHub:
+        def info(self, msg):
+            msgs.append(msg)
+    hub = MockHub()
+    hub.derive_token = Hub.derive_token.__get__(hub)
+    derived_passwd = hub.derive_token(passwd, 'pkg', now=10)
+    assert derived_passwd != passwd
+    (msg,) = msgs
+    assert "created a unique PyPI token" in msg
+    derived_token = pypitoken.token.Token.load(derived_passwd)
+    assert derived_token.restrictions == [
+        pypitoken.token.ProjectsRestriction(projects=["pkg"]),
+        pypitoken.token.DateRestriction(not_before=9, not_after=70)]
+
+
+@pytest.mark.skipif("sys.version_info < (3, 6)")
+def test_derive_devpi_token():
+    import pypitoken
+    passwd = "devpi-AgEAAhFmc2NodWx6ZS1yTlk5a0RuYQAABiBcjsOFkn7_3fn6mFoeJve_cOv-thDRL-4fQzbf_sOGjQ"
+    msgs = []
+
+    class MockHub:
+        def info(self, msg):
+            msgs.append(msg)
+    hub = MockHub()
+    hub.derive_token = Hub.derive_token.__get__(hub)
+    derived_passwd = hub.derive_token(passwd, 'pkg', now=10)
+    assert derived_passwd != passwd
+    (msg,) = msgs
+    assert "created a unique Devpi token" in msg
+    derived_token = pypitoken.token.Token.load(derived_passwd)
+    assert derived_token.restrictions == [
+        pypitoken.token.ProjectsRestriction(projects=["pkg"]),
+        pypitoken.token.DateRestriction(not_before=9, not_after=70)]
+
+
 class TestPush:
     def test_help(self, ext_devpi):
         result = ext_devpi("push", "-h")
